#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class CalendarView :
    def __init__( self):
        self.label = None
        self.type = None
        self.isDefault = None
        self.calendars = None
        pass

class __CalendarViewSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = CalendarView()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        labelValue = value['label']
        instance.label = serder.STRING.parse(labelValue)
        from netbluemind.calendar.api.CalendarViewCalendarViewType import CalendarViewCalendarViewType
        from netbluemind.calendar.api.CalendarViewCalendarViewType import __CalendarViewCalendarViewTypeSerDer__
        typeValue = value['type']
        instance.type = __CalendarViewCalendarViewTypeSerDer__().parse(typeValue)
        isDefaultValue = value['isDefault']
        instance.isDefault = serder.BOOLEAN.parse(isDefaultValue)
        calendarsValue = value['calendars']
        instance.calendars = serder.ListSerDer(serder.STRING).parse(calendarsValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        labelValue = value.label
        instance["label"] = serder.STRING.encode(labelValue)
        from netbluemind.calendar.api.CalendarViewCalendarViewType import CalendarViewCalendarViewType
        from netbluemind.calendar.api.CalendarViewCalendarViewType import __CalendarViewCalendarViewTypeSerDer__
        typeValue = value.type
        instance["type"] = __CalendarViewCalendarViewTypeSerDer__().encode(typeValue)
        isDefaultValue = value.isDefault
        instance["isDefault"] = serder.BOOLEAN.encode(isDefaultValue)
        calendarsValue = value.calendars
        instance["calendars"] = serder.ListSerDer(serder.STRING).encode(calendarsValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IInstallation_VERSION = "4.1.51102"

class IInstallation(BaseEndpoint):
    def __init__(self, apiKey, url ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/system/installation'

    def getSystemState (self):
        postUri = "/state";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.system.api.SystemState import SystemState
        from netbluemind.system.api.SystemState import __SystemStateSerDer__
        return self.handleResult__(__SystemStateSerDer__(), response)
    def ping (self, ip ):
        postUri = "/{ip}/ping";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{ip}",ip);
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def removeSubscription (self):
        postUri = "/subscription";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def runningMode (self):
        postUri = "/state/_maintenance";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def setSubscriptionContacts (self, emails ):
        postUri = "/_subscriptionContacts";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(emails)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getSubscriptionContacts (self):
        postUri = "/_subscriptionContacts";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
    def markSchemaAsUpgraded (self):
        postUri = "/version";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def postinst (self):
        postUri = "/_postinst";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def upgradeStatus (self):
        postUri = "/_upgrade";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.system.api.UpgradeStatus import UpgradeStatus
        from netbluemind.system.api.UpgradeStatus import __UpgradeStatusSerDer__
        return self.handleResult__(__UpgradeStatusSerDer__(), response)
    def getInfos (self):
        postUri = "/_infos";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.system.api.PublicInfos import PublicInfos
        from netbluemind.system.api.PublicInfos import __PublicInfosSerDer__
        return self.handleResult__(__PublicInfosSerDer__(), response)
    def resetIndex (self, index ):
        postUri = "/{index}/_resetIndex";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{index}",index);
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def resetIndexes (self):
        postUri = "/_resetIndexes";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def sendHostReport (self):
        postUri = "/_hostReport";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(serder.STRING, response)
    def getHostReport (self):
        postUri = "/_hostReport";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(serder.STRING, response)
    def deleteLogo (self):
        postUri = "/logo";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getVersion (self):
        postUri = "/version";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.system.api.InstallationVersion import InstallationVersion
        from netbluemind.system.api.InstallationVersion import __InstallationVersionSerDer__
        return self.handleResult__(__InstallationVersionSerDer__(), response)
    def setLogo (self, logo ):
        postUri = "/logo";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ByteArraySerDer.encode(logo)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getLogo (self):
        postUri = "/logo";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.system.api.CustomLogo import CustomLogo
        from netbluemind.system.api.CustomLogo import __CustomLogoSerDer__
        return self.handleResult__(__CustomLogoSerDer__(), response)
    def upgrade (self):
        postUri = "/_upgrade";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def updateSubscription (self, licence ):
        postUri = "/subscription";
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(licence)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def updateSubscriptionVersion (self, version ):
        postUri = "/subscription/_version";
        __data__ = None
        __encoded__ = None
        queryParams = {  'version': version   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def updateSubscriptionWithArchive (self, archive ):
        postUri = "/subscription/_archive";
        __data__ = None
        __encoded__ = None
        __data__ = serder.STREAM.encode(archive)
        __encoded__ = __data__
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getSubscriptionInformations (self):
        postUri = "/subscription";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.system.api.SubscriptionInformations import SubscriptionInformations
        from netbluemind.system.api.SubscriptionInformations import __SubscriptionInformationsSerDer__
        return self.handleResult__(__SubscriptionInformationsSerDer__(), response)
    def initialize (self):
        postUri = "/_initialize";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def maintenanceMode (self):
        postUri = "/state/_maintenance";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def partialUpgrade (self, from_ , to ):
        postUri = "/_partialUpgrade";
        __data__ = None
        __encoded__ = None
        queryParams = {  'from': from_  , 'to': to   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.directory.api.DirBaseValue import DirBaseValue
from netbluemind.directory.api.DirBaseValue import __DirBaseValueSerDer__
class Group (DirBaseValue):
    def __init__( self):
        DirBaseValue.__init__(self)
        self.name = None
        self.description = None
        self.properties = None
        self.hiddenMembers = None
        self.mailArchived = None
        self.memberCount = None
        pass

class __GroupSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = Group()
        __DirBaseValueSerDer__().parseInternal(value,instance)

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        descriptionValue = value['description']
        instance.description = serder.STRING.parse(descriptionValue)
        propertiesValue = value['properties']
        instance.properties = serder.MapSerDer(serder.STRING).parse(propertiesValue)
        hiddenMembersValue = value['hiddenMembers']
        instance.hiddenMembers = serder.BOOLEAN.parse(hiddenMembersValue)
        mailArchivedValue = value['mailArchived']
        instance.mailArchived = serder.BOOLEAN.parse(mailArchivedValue)
        memberCountValue = value['memberCount']
        instance.memberCount = serder.INT.parse(memberCountValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __DirBaseValueSerDer__().encodeInternal(value,instance)

        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        descriptionValue = value.description
        instance["description"] = serder.STRING.encode(descriptionValue)
        propertiesValue = value.properties
        instance["properties"] = serder.MapSerDer(serder.STRING).encode(propertiesValue)
        hiddenMembersValue = value.hiddenMembers
        instance["hiddenMembers"] = serder.BOOLEAN.encode(hiddenMembersValue)
        mailArchivedValue = value.mailArchived
        instance["mailArchived"] = serder.BOOLEAN.encode(mailArchivedValue)
        memberCountValue = value.memberCount
        instance["memberCount"] = serder.INT.encode(memberCountValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElementRRule :
    def __init__( self):
        self.frequency = None
        self.count = None
        self.until = None
        self.interval = None
        self.bySecond = None
        self.byMinute = None
        self.byHour = None
        self.byDay = None
        self.byMonthDay = None
        self.byYearDay = None
        self.byWeekNo = None
        self.byMonth = None
        pass

class __ICalendarElementRRuleSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ICalendarElementRRule()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.icalendar.api.ICalendarElementRRuleFrequency import ICalendarElementRRuleFrequency
        from netbluemind.icalendar.api.ICalendarElementRRuleFrequency import __ICalendarElementRRuleFrequencySerDer__
        frequencyValue = value['frequency']
        instance.frequency = __ICalendarElementRRuleFrequencySerDer__().parse(frequencyValue)
        countValue = value['count']
        instance.count = serder.INT.parse(countValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        untilValue = value['until']
        instance.until = __BmDateTimeSerDer__().parse(untilValue)
        intervalValue = value['interval']
        instance.interval = serder.INT.parse(intervalValue)
        bySecondValue = value['bySecond']
        instance.bySecond = serder.ListSerDer(serder.INT).parse(bySecondValue)
        byMinuteValue = value['byMinute']
        instance.byMinute = serder.ListSerDer(serder.INT).parse(byMinuteValue)
        byHourValue = value['byHour']
        instance.byHour = serder.ListSerDer(serder.INT).parse(byHourValue)
        from netbluemind.icalendar.api.ICalendarElementRRuleWeekDay import ICalendarElementRRuleWeekDay
        from netbluemind.icalendar.api.ICalendarElementRRuleWeekDay import __ICalendarElementRRuleWeekDaySerDer__
        byDayValue = value['byDay']
        instance.byDay = serder.ListSerDer(__ICalendarElementRRuleWeekDaySerDer__()).parse(byDayValue)
        byMonthDayValue = value['byMonthDay']
        instance.byMonthDay = serder.ListSerDer(serder.INT).parse(byMonthDayValue)
        byYearDayValue = value['byYearDay']
        instance.byYearDay = serder.ListSerDer(serder.INT).parse(byYearDayValue)
        byWeekNoValue = value['byWeekNo']
        instance.byWeekNo = serder.ListSerDer(serder.INT).parse(byWeekNoValue)
        byMonthValue = value['byMonth']
        instance.byMonth = serder.ListSerDer(serder.INT).parse(byMonthValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.icalendar.api.ICalendarElementRRuleFrequency import ICalendarElementRRuleFrequency
        from netbluemind.icalendar.api.ICalendarElementRRuleFrequency import __ICalendarElementRRuleFrequencySerDer__
        frequencyValue = value.frequency
        instance["frequency"] = __ICalendarElementRRuleFrequencySerDer__().encode(frequencyValue)
        countValue = value.count
        instance["count"] = serder.INT.encode(countValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        untilValue = value.until
        instance["until"] = __BmDateTimeSerDer__().encode(untilValue)
        intervalValue = value.interval
        instance["interval"] = serder.INT.encode(intervalValue)
        bySecondValue = value.bySecond
        instance["bySecond"] = serder.ListSerDer(serder.INT).encode(bySecondValue)
        byMinuteValue = value.byMinute
        instance["byMinute"] = serder.ListSerDer(serder.INT).encode(byMinuteValue)
        byHourValue = value.byHour
        instance["byHour"] = serder.ListSerDer(serder.INT).encode(byHourValue)
        from netbluemind.icalendar.api.ICalendarElementRRuleWeekDay import ICalendarElementRRuleWeekDay
        from netbluemind.icalendar.api.ICalendarElementRRuleWeekDay import __ICalendarElementRRuleWeekDaySerDer__
        byDayValue = value.byDay
        instance["byDay"] = serder.ListSerDer(__ICalendarElementRRuleWeekDaySerDer__()).encode(byDayValue)
        byMonthDayValue = value.byMonthDay
        instance["byMonthDay"] = serder.ListSerDer(serder.INT).encode(byMonthDayValue)
        byYearDayValue = value.byYearDay
        instance["byYearDay"] = serder.ListSerDer(serder.INT).encode(byYearDayValue)
        byWeekNoValue = value.byWeekNo
        instance["byWeekNo"] = serder.ListSerDer(serder.INT).encode(byWeekNoValue)
        byMonthValue = value.byMonth
        instance["byMonth"] = serder.ListSerDer(serder.INT).encode(byMonthValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class BmDateTime :
    def __init__( self):
        self.iso8601 = None
        self.timezone = None
        self.precision = None
        pass

class __BmDateTimeSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = BmDateTime()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        iso8601Value = value['iso8601']
        instance.iso8601 = serder.STRING.parse(iso8601Value)
        timezoneValue = value['timezone']
        instance.timezone = serder.STRING.parse(timezoneValue)
        from netbluemind.core.api.date.BmDateTimePrecision import BmDateTimePrecision
        from netbluemind.core.api.date.BmDateTimePrecision import __BmDateTimePrecisionSerDer__
        precisionValue = value['precision']
        instance.precision = __BmDateTimePrecisionSerDer__().parse(precisionValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        iso8601Value = value.iso8601
        instance["iso8601"] = serder.STRING.encode(iso8601Value)
        timezoneValue = value.timezone
        instance["timezone"] = serder.STRING.encode(timezoneValue)
        from netbluemind.core.api.date.BmDateTimePrecision import BmDateTimePrecision
        from netbluemind.core.api.date.BmDateTimePrecision import __BmDateTimePrecisionSerDer__
        precisionValue = value.precision
        instance["precision"] = __BmDateTimePrecisionSerDer__().encode(precisionValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IGroup_VERSION = "4.1.51102"

class IGroup(BaseEndpoint):
    def __init__(self, apiKey, url ,domainUid ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/groups/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}',domainUid)

    def getExpandedUserMembers (self, uid ):
        postUri = "/{uid}/expandedusersmembers";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.group.api.Member import Member
        from netbluemind.group.api.Member import __MemberSerDer__
        return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)
    def allUids (self):
        postUri = "/_alluids";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
    def update (self, uid , group ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        __data__ = __GroupSerDer__().encode(group)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def byName (self, name ):
        postUri = "/byName/{name}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{name}",name);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
    def delete (self, uid ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def remove (self, uid , members ):
        postUri = "/{uid}/members";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.group.api.Member import Member
        from netbluemind.group.api.Member import __MemberSerDer__
        __data__ = serder.ListSerDer(__MemberSerDer__()).encode(members)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getParents (self, uid ):
        postUri = "/{uid}/parents";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
    def search (self, query ):
        postUri = "/_search";
        __data__ = None
        __encoded__ = None
        from netbluemind.group.api.GroupSearchQuery import GroupSearchQuery
        from netbluemind.group.api.GroupSearchQuery import __GroupSearchQuerySerDer__
        __data__ = __GroupSearchQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
    def getExpandedMembers (self, uid ):
        postUri = "/{uid}/expandedmembers";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.group.api.Member import Member
        from netbluemind.group.api.Member import __MemberSerDer__
        return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)
    def byEmail (self, email ):
        postUri = "/byEmail/{email}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{email}",email);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
    def create (self, uid , group ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        __data__ = __GroupSerDer__().encode(group)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def setRoles (self, uid , roles ):
        postUri = "/{uid}/roles";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        __data__ = serder.SetSerDer(serder.STRING).encode(roles)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getRoles (self, uid ):
        postUri = "/{uid}/roles";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
    def add (self, uid , members ):
        postUri = "/{uid}/members";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.group.api.Member import Member
        from netbluemind.group.api.Member import __MemberSerDer__
        __data__ = serder.ListSerDer(__MemberSerDer__()).encode(members)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getByExtId (self, extid ):
        postUri = "/_extid/{extid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{extid}",extid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
    def touch (self, uid ):
        postUri = "/{uid}/_touch";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def setExtId (self, uid , arg1 ):
        postUri = "/{uid}/_extId";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        __data__ = serder.STRING.encode(arg1)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getComplete (self, uid ):
        postUri = "/{uid}/complete";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
    def getGroupsWithRoles (self, roles ):
        postUri = "/_rolegroups";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(roles)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
    def createWithExtId (self, uid , extid , group ):
        postUri = "/{uid}/{extid}/createwithextid";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        postUri = postUri.replace("{extid}",extid);
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        __data__ = __GroupSerDer__().encode(group)
        __encoded__ = json.dumps(__data__)
        queryParams = {     };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getMembers (self, uid ):
        postUri = "/{uid}/members";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
        from netbluemind.group.api.Member import Member
        from netbluemind.group.api.Member import __MemberSerDer__
        return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class PartGeneration :
    def __init__( self):
        self.id = None
        self.generationId = None
        self.begin = None
        self.end = None
        self.size = None
        self.tag = None
        self.server = None
        self.withWarnings = None
        self.withErrors = None
        self.valid = None
        self.datatype = None
        pass

class __PartGenerationSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = PartGeneration()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        idValue = value['id']
        instance.id = serder.INT.parse(idValue)
        generationIdValue = value['generationId']
        instance.generationId = serder.INT.parse(generationIdValue)
        beginValue = value['begin']
        instance.begin = serder.DATE.parse(beginValue)
        endValue = value['end']
        instance.end = serder.DATE.parse(endValue)
        sizeValue = value['size']
        instance.size = serder.LONG.parse(sizeValue)
        tagValue = value['tag']
        instance.tag = serder.STRING.parse(tagValue)
        serverValue = value['server']
        instance.server = serder.STRING.parse(serverValue)
        withWarningsValue = value['withWarnings']
        instance.withWarnings = serder.BOOLEAN.parse(withWarningsValue)
        withErrorsValue = value['withErrors']
        instance.withErrors = serder.BOOLEAN.parse(withErrorsValue)
        from netbluemind.dataprotect.api.GenerationStatus import GenerationStatus
        from netbluemind.dataprotect.api.GenerationStatus import __GenerationStatusSerDer__
        validValue = value['valid']
        instance.valid = __GenerationStatusSerDer__().parse(validValue)
        datatypeValue = value['datatype']
        instance.datatype = serder.STRING.parse(datatypeValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        idValue = value.id
        instance["id"] = serder.INT.encode(idValue)
        generationIdValue = value.generationId
        instance["generationId"] = serder.INT.encode(generationIdValue)
        beginValue = value.begin
        instance["begin"] = serder.DATE.encode(beginValue)
        endValue = value.end
        instance["end"] = serder.DATE.encode(endValue)
        sizeValue = value.size
        instance["size"] = serder.LONG.encode(sizeValue)
        tagValue = value.tag
        instance["tag"] = serder.STRING.encode(tagValue)
        serverValue = value.server
        instance["server"] = serder.STRING.encode(serverValue)
        withWarningsValue = value.withWarnings
        instance["withWarnings"] = serder.BOOLEAN.encode(withWarningsValue)
        withErrorsValue = value.withErrors
        instance["withErrors"] = serder.BOOLEAN.encode(withErrorsValue)
        from netbluemind.dataprotect.api.GenerationStatus import GenerationStatus
        from netbluemind.dataprotect.api.GenerationStatus import __GenerationStatusSerDer__
        validValue = value.valid
        instance["valid"] = __GenerationStatusSerDer__().encode(validValue)
        datatypeValue = value.datatype
        instance["datatype"] = serder.STRING.encode(datatypeValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class JobPlanification :
    def __init__( self):
        self.kind = None
        self.rec = None
        self.lastRun = None
        self.nextRun = None
        self.domain = None
        pass

class __JobPlanificationSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = JobPlanification()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.scheduledjob.api.PlanKind import PlanKind
        from netbluemind.scheduledjob.api.PlanKind import __PlanKindSerDer__
        kindValue = value['kind']
        instance.kind = __PlanKindSerDer__().parse(kindValue)
        from netbluemind.scheduledjob.api.JobRec import JobRec
        from netbluemind.scheduledjob.api.JobRec import __JobRecSerDer__
        recValue = value['rec']
        instance.rec = __JobRecSerDer__().parse(recValue)
        lastRunValue = value['lastRun']
        instance.lastRun = serder.DATE.parse(lastRunValue)
        nextRunValue = value['nextRun']
        instance.nextRun = serder.DATE.parse(nextRunValue)
        domainValue = value['domain']
        instance.domain = serder.STRING.parse(domainValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.scheduledjob.api.PlanKind import PlanKind
        from netbluemind.scheduledjob.api.PlanKind import __PlanKindSerDer__
        kindValue = value.kind
        instance["kind"] = __PlanKindSerDer__().encode(kindValue)
        from netbluemind.scheduledjob.api.JobRec import JobRec
        from netbluemind.scheduledjob.api.JobRec import __JobRecSerDer__
        recValue = value.rec
        instance["rec"] = __JobRecSerDer__().encode(recValue)
        lastRunValue = value.lastRun
        instance["lastRun"] = serder.DATE.encode(lastRunValue)
        nextRunValue = value.nextRun
        instance["nextRun"] = serder.DATE.encode(nextRunValue)
        domainValue = value.domain
        instance["domain"] = serder.STRING.encode(domainValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class MessageContext :
    def __init__( self):
        self.fromIdentity = None
        self.recipients = None
        self.messageClass = None
        self.subject = None
        pass

class __MessageContextSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = MessageContext()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.mailflow.common.api.SendingAs import SendingAs
        from netbluemind.mailflow.common.api.SendingAs import __SendingAsSerDer__
        fromIdentityValue = value['fromIdentity']
        instance.fromIdentity = __SendingAsSerDer__().parse(fromIdentityValue)
        from netbluemind.mailflow.common.api.Recipient import Recipient
        from netbluemind.mailflow.common.api.Recipient import __RecipientSerDer__
        recipientsValue = value['recipients']
        instance.recipients = serder.ListSerDer(__RecipientSerDer__()).parse(recipientsValue)
        messageClassValue = value['messageClass']
        instance.messageClass = serder.STRING.parse(messageClassValue)
        subjectValue = value['subject']
        instance.subject = serder.STRING.parse(subjectValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.mailflow.common.api.SendingAs import SendingAs
        from netbluemind.mailflow.common.api.SendingAs import __SendingAsSerDer__
        fromIdentityValue = value.fromIdentity
        instance["fromIdentity"] = __SendingAsSerDer__().encode(fromIdentityValue)
        from netbluemind.mailflow.common.api.Recipient import Recipient
        from netbluemind.mailflow.common.api.Recipient import __RecipientSerDer__
        recipientsValue = value.recipients
        instance["recipients"] = serder.ListSerDer(__RecipientSerDer__()).encode(recipientsValue)
        messageClassValue = value.messageClass
        instance["messageClass"] = serder.STRING.encode(messageClassValue)
        subjectValue = value.subject
        instance["subject"] = serder.STRING.encode(subjectValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class CalendarLookupResponse :
    def __init__( self):
        self.uid = None
        self.name = None
        self.type = None
        self.email = None
        self.memberCount = None
        self.ownerUid = None
        pass

class __CalendarLookupResponseSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = CalendarLookupResponse()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        uidValue = value['uid']
        instance.uid = serder.STRING.parse(uidValue)
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        from netbluemind.calendar.api.CalendarLookupResponseType import CalendarLookupResponseType
        from netbluemind.calendar.api.CalendarLookupResponseType import __CalendarLookupResponseTypeSerDer__
        typeValue = value['type']
        instance.type = __CalendarLookupResponseTypeSerDer__().parse(typeValue)
        emailValue = value['email']
        instance.email = serder.STRING.parse(emailValue)
        memberCountValue = value['memberCount']
        instance.memberCount = serder.INT.parse(memberCountValue)
        ownerUidValue = value['ownerUid']
        instance.ownerUid = serder.STRING.parse(ownerUidValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        uidValue = value.uid
        instance["uid"] = serder.STRING.encode(uidValue)
        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        from netbluemind.calendar.api.CalendarLookupResponseType import CalendarLookupResponseType
        from netbluemind.calendar.api.CalendarLookupResponseType import __CalendarLookupResponseTypeSerDer__
        typeValue = value.type
        instance["type"] = __CalendarLookupResponseTypeSerDer__().encode(typeValue)
        emailValue = value.email
        instance["email"] = serder.STRING.encode(emailValue)
        memberCountValue = value.memberCount
        instance["memberCount"] = serder.INT.encode(memberCountValue)
        ownerUidValue = value.ownerUid
        instance["ownerUid"] = serder.STRING.encode(ownerUidValue)
        return instance

